guerrillagardening.org - Index
Keywords: PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum

| Welcome, Guest. Please login or register. Did you miss your activation email? December 06, 2014, 01:12:12 AM
News: Welcome to the GuerrillaGardening.org Community, a place for guerrillas and wannabe guerrillas from around the world. Enlist with a username and password to share your guerrilla gardening plans, activity and advice. Find support or just go for it solo, sow the seed and get something growing. Click here to return to the home page: www.GuerrillaGardening.org You can also connect with people at the GuerrillaGardening.org Facebook group here: http://www.facebook.com/guerrillagardening TIP: To get alerts to replies to your messages click PROFILE then click "Look and Layout Preferences" on the left hand side menu. There is a check box to get alerts, and a check box to see recent posts at the top.

guerrillagardening.org |
Board name | Topics | Posts | Last post
Regional Boards
| Global Forum For guerrillas any where to share things with everyone else on Planet Earth. Child Boards: Seed Bomb R&D, 1 May - International Sunflower Guerrilla Gardening Day , 9 October - International Tulip Guerrilla Gardening Day, Edibles, Student / Media Enquiries, Books | 312 | 1267 | November 27, 2014, 06:03:03 AM in Re: planting around stre... by melgibson
| Rest of World If your country or region is not listed below please e-mail richard@guerrillagardening.org and I will set up a specific board for you. | 32 | 124 | November 16, 2013, 01:48:58 AM in Re: Bamboo!!!!!! by fuzzylogic
| UK Child Boards: London, Bath, Bedfordshire, Belfast, Berkshire, Birmingham, Blackburn, Bolton, Bournemouth, Brighton, Bristol, Buckinghamshire, Cambridgeshire, Cheshire, Chichester, Colchester, Coventry, Cornwall, Crewkerne, Derby, Doncaster, Dorchester, County Durham, Exeter, Gloucestershire, Hampshire, Hertfordshire, Hull, Isle of Wight, Jersey, Kent, Lancashire, Leeds / Bradford, Leicester, Lincolnshire, Liverpool, Macclesfield, Manchester, Malvern, Marlborough, Middlesex, Newcastle, Norfolk, Northern Ireland, Northants, Nottinghamshire, Okehampton, Oxfordshire, Plymouth, Portsmouth, Reading, Scotland, Sheffield, Shropshire, Somerset, Southampton, Southend-On-Sea , Stoke-on-Trent, Suffolk, Surrey, Thornaby on Tees, Torquay, Totnes, Wales, Wakefield, Warrington, Wiltshire, Wirral, Worcestershire, Worthing, Yorkshire | 1283 | 4250 | November 11, 2014, 02:41:09 PM in Re: GG Headingley Leeds by roseboast
| USA Child Boards: Alabama, Arkansas, Arizona, Atlanta, Baltimore, California, Chattanooga, Chicago, Colorado, Connecticut, Delaware, Detroit, Florida, Hawaii, Indiana, Iowa, Kansas, Kentucky, Maryland, Maine & Massachusetts, Memphis, Tennessee , Michigan, Milwaukee, Minnesota, Mississippi, Missouri, Nashville, Nebraska, Nevada, New Jersey, New Mexico, New Orleans, New York, North Carolina, Ohio, Oklahoma, Olympia, Oregon, Ouachita AR, Pennsylvania, Portland, Pittsburgh, Philadelphia, Rhode Island, Virginia, Seattle, South Carolina, Texas, Utah, Vermont, Washington DC, Washington State, Wisconsin, Wyoming, Elsewhere | 689 | 2146 | November 16, 2014, 09:31:37 PM in Re: Monday June 8th @10p... by PurpleIrisDude
| Germany Child Boards: Anderswo, Augsburg, Berlin, Bielefeld, Braunschweig, Bremen, Chemnitz, Dresden, Duesseldorf, Duisburg, Essen, Frankfurt am Main, Freiburg, Hamburg, Hannover, Karlsrue, Kehl, Kiel, Koeln, Landkreis Schweinfurt, Leipzig, Luebeck, Magdeburg, Muenchen, Muenster, Rostock, Stuttgart, Trier, Wuerzburg | 338 | 924 | August 20, 2014, 08:56:18 AM in Gruppe in Frankfurt am M... by Poison Ivy
| Australia Child Boards: Adelaide, Brisbane, Canberra, Casey, Geelong, Glen Waverley, Gold Coast-Tweed, Hobart, Ipswich, Maleny, Melbourne, Mornington Peninsula, Newcastle, Perth, Sydney, Wollongong, The TV show | 99 | 547 | September 05, 2014, 03:20:24 AM in Anyone keen to vegebomb ... by Peter
| New Zealand | 21 | 67 | August 31, 2013, 10:10:15 AM in Join the war on terra wi... by Niloufer
| Canada Child Boards: Brampton, Calgary, Carbon, Edmonton, London, Halifax, Hamilton, Manitoba, Montreal, Ottawa, Quebec, Toronto, Vancouver, Waterloo, Windsor, Lethbridge | 88 | 207 | June 20, 2014, 09:59:09 AM in Re: Welland, Ontaria, Ca... by krisrw
| Republic of Ireland | 62 | 474 | November 25, 2014, 11:03:43 PM in Woodchip Mulch by tampopo
| France Child Boards: Bordeaux, Cholet, Grenoble, Lille, Lyon, Nantes, Paris, Toulouse | 32 | 87 | November 02, 2014, 08:09:40 PM in "We'll always have Paris... by tampopo
| Austria Child Boards: Graz, Linz, Vorarlberg, Wien | 21 | 48 | May 13, 2014, 12:15:55 AM in Die Saison 2014 f?r Guer... by agmoos
| Belarus | 1 | 1 | April 03, 2010, 07:43:31 PM in Looking for guerilla gar... by Lesja
| Belgium | 13 | 46 | October 30, 2011, 04:42:26 PM in Re: welcome by Corrinne
| Bulgaria | 0 | 0 | N/A in N/A by N/A
| Czech Republic | 4 | 7 | February 09, 2011, 12:18:51 PM in Re: Guerilla Gardening i... by darlenehill19
| Denmark | 18 | 39 | May 21, 2014, 01:28:03 PM in Guerrilla i Aarhus by anto1046
| Finland | 2 | 5 | October 27, 2010, 06:22:09 PM in Re: Guerilla Gardening i... by Gareth
| Egypt | 1 | 1 | March 15, 2011, 02:43:35 PM in New Guerrilla Gardening ... by Richard _001
| Georgia | 3 | 3 | March 19, 2014, 01:20:00 PM in Guerrilla gardening move... by Niloufer
| Greece | 3 | 8 | April 24, 2013, 02:13:09 PM in Thessaloniki by psmert
| Hungary | 6 | 25 | April 26, 2014, 03:16:51 PM in Buda can you spare some ... by tampopo
| Israel | 4 | 10 | July 26, 2010, 09:26:16 PM in Roof Gardening - Jerusal... by Digitalboaz
| Italy | 37 | 80 | May 23, 2013, 04:35:29 PM in Blog on Seed Bombs and M... by Niloufer
| Latvia | 1 | 1 | October 27, 2009, 07:49:12 PM in Dig on 28. Oct 21:45 , R... by Toms
| Libya | 1 | 1 | December 21, 2006, 08:47:14 PM in Guerrilla Gardening in T... by Richard _001
| Lithuania | 3 | 21 | July 07, 2013, 06:22:06 PM in Grand Tour of the Baltic... by tampopo
| Netherlands | 60 | 180 | April 11, 2014, 10:52:09 PM in Almere (again) by Manov
| Norway Child Boards: Bergen | 3 | 12 | December 03, 2011, 01:51:27 PM in Report on guerrilla gard... by Richard _001
| Poland Child Boards: Gostynin | 10 | 14 | May 13, 2013, 12:30:07 PM in Detailed article on guer... by Richard _001
| Portugal | 10 | 28 | August 10, 2013, 07:38:51 PM in Mouraria, Lisbon... by tampopo
| Romania | 3 | 9 | October 20, 2014, 04:04:58 PM in Please support a good ca... by tampopo
| Russia | 4 | 6 | April 15, 2010, 12:54:31 PM in Re: Ok, Who live in Mosc... by youlooktoofast
| Spain | 32 | 126 | January 28, 2014, 03:36:40 PM in Re: Barcelona by Averroes
| Slovenia | 1 | 5 | February 18, 2014, 05:24:18 PM in Maribor, European Capita... by tampopo
| Sweden | 24 | 89 | March 11, 2014, 01:03:16 PM in Mossgraffiti p? Betong, ... by ooKAH
| Switzerland | 23 | 56 | February 21, 2014, 06:34:11 PM in Online-Umfrage zum Thema... by DailyFlower
| Turkey | 2 | 8 | December 30, 2011, 02:00:53 PM in group to action by nenzj101
| Africa Child Boards: Botswana, Somalia, Uganda, South Africa | 5 | 17 | July 25, 2011, 04:01:34 PM in Re: South African blogge... by Secret-Gardener
| Argentina | 5 | 7 | October 11, 2012, 06:46:28 PM in VAMOSS ACTIVAMOS GUERRIL... by nicolancel
| Brazil Child Boards: Brasilia, Campo Grande, Mato Grosso do Sul, Sao Paulo, Maraba | 7 | 15 | June 05, 2013, 11:50:12 PM in Re: GG in São Paulo by Burgos
| Chile | 4 | 10 | November 03, 2010, 10:18:45 PM in Honeymoon destination? by johnphall
| Colombia | 2 | 5 | August 26, 2013, 05:51:49 PM in Re: Bienvenidos by DIENTEDELEON
| Ecuador | 1 | 3 | September 07, 2009, 06:49:23 PM in Re: Guerrilla Gardening ... by MelasPJ
| Guatemala | 0 | 0 | N/A in N/A by N/A
| Jamaica | 1 | 1 | April 02, 2013, 10:58:55 PM in 22 April 2013. GG event by Richard _001
| Mexico | 9 | 23 | July 20, 2011, 04:50:09 PM in Nuevo Animos en Guadalaj... by arqcova
| Peru | 2 | 5 | February 26, 2010, 03:17:26 AM in Re: unanse :) by Alfie1990
| China Child Boards: Hong Kong | 1 | 3 | May 23, 2014, 03:09:18 AM in Re: Happy Valley by Michael Leung
| Puerto Rico | 1 | 1 | April 28, 2010, 12:11:30 PM in Guerrilla Gardening Repo... by antigonum cajan
| India | 3 | 5 | February 14, 2014, 11:51:22 PM in Indian Facebook guerrill... by tampopo
| Japan | 13 | 41 | October 03, 2014, 07:18:41 PM in Tokyo fun with sunflower... by tampopo
| Malaysia | 2 | 32 | October 12, 2010, 08:23:37 PM in Re: Plant List by linggobayu
| Maldives | 0 | 0 | N/A in N/A by N/A
| Nepal | 0 | 0 | N/A in N/A by N/A
| Singapore | 2 | 4 | December 10, 2013, 05:15:44 AM in Looking for 'kaki's by kiwi
| South Korea | 4 | 11 | May 28, 2014, 12:45:13 PM in Guerrilla Gardening Catc... by Niloufer
| Sri Lanka | 1 | 1 | May 01, 2008, 07:52:36 PM in "Shock gardens" Guerrill... by Richard _001
| Taiwan | 1 | 2 | November 13, 2011, 06:50:24 AM in Re: Green Taiwan - anoth... by greentaiwan
| Thailand | 4 | 12 | August 31, 2014, 02:52:37 PM in Re: hello thailand ;) by pumelike
guerrillagardening.org - Info Center
Forum Stats
Total Topics: 3,314 Total Posts: 11,120 Latest Post: "Re: planting around stre..." (November 27, 2014, 06:03:03 AM) View the most recent posts on the forum. [More Stats] | Total Members: 41,959 Latest Member: nmougin90
Users Online
| 73 Guests, 0 Users
Login (Forgot your password?)
Username: | Password: | Minutes to stay logged in: | Always stay logged in: |

Login with username, password and session length

| Powered by SMF 1.1.19 | SMF © 2013, Simple Machines |

Loading...